
.. py:currentmodule:: pythreejs

FogExp2
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: FogExp2(color="white", density=0.00025, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.ThreeWidget`.

    Three.js docs: https://threejs.org/docs/#api/scenes/FogExp2


    .. py:attribute:: name

        .. sourcecode:: python

            Unicode('', allow_none=False).tag(sync=True)

    .. py:attribute:: color

        .. sourcecode:: python

            Unicode("white", allow_none=False).tag(sync=True)

    .. py:attribute:: density

        .. sourcecode:: python

            CFloat(0.00025, allow_none=False).tag(sync=True)

